@@ -1,8 +1,8 @@
 import { useCallback, useState } from 'react';
 
+import { t } from '@grafana/i18n';
 import { Modal, ToolbarButton } from '@grafana/ui';
-import { t } from 'app/core/internationalization';
-import { useSelector } from 'app/types';
+import { useSelector } from 'app/types/store';
 
 import { getExploreItemSelector } from '../../state/selectors';
 
